@@ -706,3 +706,13 @@ is_fastboot_active() {
 	done
 	return 1
 }
+
+# This function does not actually belong here; it is duct-tape solution
+# for #901289.
+logsave_best_effort () {
+	if [ -x /sbin/logsave ] ; then
+		logsave -s "${FSCK_LOGFILE}" "$@"
+	else
+		"$@"
+	fi
+}
